@@ -322,25 +322,33 @@ def load_dataset(
         try:
 
             path = os.path.dirname(verticapy.__file__)
-            path += f"/data/{dataset_name}.csv"
-            if not (copy_cols):
-                copy_cols = [quote_ident(col) for col in dtype]
-            copy_cols = ", ".join(copy_cols)
-            query = (
-                "COPY {0}.{1}({2}) FROM {3} DELIMITER ',' NULL '' "
-                "ENCLOSED BY '\"' ESCAPE AS '\\' SKIP 1;"
-            ).format(schema, name, copy_cols, "{}")
+            if dataset_name in ("laliga",):
+                path += f"/data/{dataset_name}/*.json"
+                query = "COPY {0}.{1} FROM {2} PARSER FJsonParser();".format(
+                    schema, name, "{}"
+                )
+            else:
+                path += f"/data/{dataset_name}.csv"
+                if not (copy_cols):
+                    copy_cols = [quote_ident(col) for col in dtype]
+                copy_cols = "(" + ", ".join(copy_cols) + ")"
+                query = (
+                    "COPY {0}.{1}{2} FROM {3} DELIMITER ',' NULL '' "
+                    "ENCLOSED BY '\"' ESCAPE AS '\\' SKIP 1;"
+                ).format(schema, name, copy_cols, "{}")
 
             cur = current_cursor()
 
-            if isinstance(cur, vertica_python.vertica.cursor.Cursor):
+            if isinstance(cur, vertica_python.vertica.cursor.Cursor) and (
+                dataset_name not in ("laliga",)
+            ):
 
                 query = query.format("STDIN")
                 executeSQL(query, title="Ingesting the data.", method="copy", path=path)
 
             else:
 
-                query = query.format("LOCAL '{0}'".format(path))
+                query = query.format(f"LOCAL '{path}'")
                 executeSQL(query, title="Ingesting the data.")
 
             executeSQL("COMMIT;", title="Commit.")
@@ -565,6 +573,50 @@ vDataFrame
     )
 
 
+# ---#
+def load_laliga(schema: str = "public", name: str = "laliga"):
+    """
+---------------------------------------------------------------------------
+Ingests the La-Liga dataset into the Vertica database. This dataset is ideal
+to test complex data types. If a table with the same name and schema already 
+exists, this function will create a vDataFrame from the input relation.
+
+Parameters
+----------
+schema: str, optional
+    Schema of the new relation. If empty, a temporary local table will be
+    created.
+name: str, optional
+    Name of the new relation.
+
+Returns
+-------
+vDataFrame
+    the Cities vDataFrame.
+    """
+    return load_dataset(
+        schema,
+        name,
+        {
+            "away_score": "int",
+            "away_team": 'Row("away_team_gender" varchar, "away_team_group" varchar, "away_team_id" int, "away_team_name" varchar, "country" Row("id" int, "name" varchar), "managers" Array[Row("country" Row("id" int, "name" varchar), "dob" date, "id" int, "name" varchar, "nickname" varchar)])',
+            "competition": 'Row("competition_id" int, "competition_name" varchar, "country_name" varchar)',
+            "competition_stage": 'Row("id" int, "name" varchar)',
+            "home_score": "int",
+            "home_team": 'Row("country" Row("id" int, "name" varchar), "home_team_gender" varchar, "home_team_group" varchar, "home_team_id" int, "home_team_name" varchar, "managers" Array[Row("country" Row("id" int, "name" varchar), "dob" date, "id" int, "name" varchar, "nickname" varchar)])',
+            "kick_off": "time",
+            "last_updated": "date",
+            "match_date": "date",
+            "match_id": "int",
+            "match_status": "varchar",
+            "match_week": "int",
+            "metadata": 'Row("data_version" date, "shot_fidelity_version" int, "xy_fidelity_version" int)',
+            "season": 'Row("season_id" int, "season_name" varchar)',
+        },
+        dataset_name="laliga",
+    )
+
+
 # ---#
 def load_market(schema: str = "public", name: str = "market"):
     """
